---
title: ListChange
---

This enum describes the changes of the given collections of items.

``` swift
public enum ListChange<Item> 
```

## Inheritance

`CustomStringConvertible`

## Enumeration Cases

### `insert`

A new item was inserted on the given index path.

``` swift
case insert(_ item: Item, index: IndexPath)
```

### `move`

An item was moved from `fromIndex` to `toIndex`. Moving an item also automatically mean you should reload its UI.

``` swift
case move(_ item: Item, fromIndex: IndexPath, toIndex: IndexPath)
```

### `update`

An item was updated at the given `index`. An `update` change is also automatically generated by moving an item.

``` swift
case update(_ item: Item, index: IndexPath)
```

### `remove`

An item was removed from the given `index`.

``` swift
case remove(_ item: Item, index: IndexPath)
```

## Properties

### `description`

Returns pretty `ListChange` description

``` swift
public var description: String 
```
